@@ -25,10 +25,10 @@ class App extends Component<{}> {
     return (
       <View style={styles.container}>
         <Text style={styles.welcome}>
-          This is Benoits   eapp !
+          This is Benoit app !
         </Text>
         <Text style={styles.instructions}>
-          Wanna get started ? Edit App.js
+          Wanna get stared ? Edit App.js
         </Text>
         <Text style={styles.instructions}>
           {instructions}
